@@ -24,11 +24,17 @@
  * Use these functions to print textually event fields. 
  */
 
-
-
+#include <lttv/event.h>
+#ifdef BABEL_CLEANUP
 void lttv_print_field(LttEvent *e, struct marker_field *f, GString *s,
 		gboolean field_names, LttvTracefileState *tfs);
 
 void lttv_event_to_string(LttEvent *e, GString *s, gboolean mandatory_fields,
 		gboolean field_names, LttvTracefileState *tfs);
+#endif
+void lttv_event_to_string(LttvEvent *event,
+			  GString *a_string,
+			  gboolean field_names,
+			  gboolean long_version);
+void lttv_event_get_name(LttvEvent *event,GString *a_string);
 
