@@ -24,10 +24,7 @@
 #include <gdk/gdk.h>
 #include <string.h>
 
-#include <ltt/trace.h>
-
 #include <lttv/lttv.h>
-#include <lttv/tracecontext.h>
 #include <lttvwindow/lttvwindow.h>
 #include <lttv/state.h>
 #include <lttv/hook.h>
@@ -132,7 +129,7 @@ void histo_drawing_data_request(histoDrawing_t *drawing,
 }
  
 
-void histo_drawing_data_request_begin(EventsRequest *events_request, LttvTracesetState *tss)
+void histo_drawing_data_request_begin(EventsRequest *events_request, LttvTraceset *traceset)
 {
   g_debug("Begin of data request");
   HistoControlFlowData *cfd = events_request->viewer_data;
@@ -152,7 +149,7 @@ void histo_drawing_data_request_begin(EventsRequest *events_request, LttvTracese
 
  }
 
-void histo_drawing_chunk_begin(EventsRequest *events_request, LttvTracesetState *tss)
+void histo_drawing_chunk_begin(EventsRequest *events_request, LttvTraceset *traceset)
 {
   g_debug("Begin of chunk");
   HistoControlFlowData *cfd = events_request->viewer_data;
@@ -164,7 +161,7 @@ void histo_drawing_chunk_begin(EventsRequest *events_request, LttvTracesetState
 
 
 void histo_drawing_request_expose(EventsRequest *events_request,
-                            LttvTracesetState *tss,
+                            LttvTraceset *traceset,
                             LttTime end_time)
 {
   HistoControlFlowData *cfd = events_request->viewer_data;
@@ -921,20 +918,7 @@ void drawing_remove_square(histoDrawing_t *drawing,
 
 void histo_drawing_update_ruler(histoDrawing_t *drawing, TimeWindow *time_window)
 {
-  GtkRequisition req;
-  GdkRectangle rect;
-  
-  req.width = drawing->ruler->allocation.width;
-  req.height = drawing->ruler->allocation.height;
-
- 
-  rect.x = 0;
-  rect.y = 0;
-  rect.width = req.width;
-  rect.height = req.height;
-
   gtk_widget_queue_draw(drawing->ruler);
-  //gtk_widget_draw( drawing->ruler, &rect);
 }
 
 /* Redraw the ruler */
@@ -1052,19 +1036,7 @@ histo_expose_ruler( GtkWidget *widget, GdkEventExpose *event, gpointer user_data
 
  void histo_drawing_update_vertical_ruler(histoDrawing_t *drawing)//, TimeWindow *time_window)
 {
-  GtkRequisition req;
-  GdkRectangle rect;
-  
-  req.width = drawing->vertical_ruler->allocation.width;
-  req.height = drawing->vertical_ruler->allocation.height;
- 
-  rect.x = 0;
-  rect.y = 0;
-  rect.width = req.width;
-  rect.height = req.height;
-
   gtk_widget_queue_draw(drawing->vertical_ruler);
-  //gtk_widget_draw( drawing->ruler, &rect);
 }
 
 /* notify mouse on ruler */
